pub enum TreeSelector {
SubtreeSelector(SubtreeSelector),
PropertySelector(PropertySelector),
UnknownOrdinal_(u64),
}Expand description
TreeSelector represents a selection request on a hierarchy of named nodes, with named properties on those nodes.
Variants
Implementations
Sourceimpl TreeSelector
impl TreeSelector
pub fn is_unknown(&self) -> bool