#[repr(C)]pub struct All {}Trait Implementations
Sourceimpl CompatFrom<All> for All
impl CompatFrom<All> for All
Sourcefn compat_from(value: All) -> Self
fn compat_from(value: All) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<All> for All
impl CompatFrom<All> for All
Sourcefn compat_from(value: All) -> Self
fn compat_from(value: All) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<All, ___E> for &'a Allwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<All, ___E> for &'a Allwhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<All, ___E> for Allwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<All, ___E> for Allwhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<'a, ___E> EncodeOption<Box<'static, All>, ___E> for &'a All
impl<'a, ___E> EncodeOption<Box<'static, All>, ___E> for &'a All
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, All>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, All>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, All>, ___E> for All
impl<___E> EncodeOption<Box<'static, All>, ___E> for All
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, All>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, All>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWireRef<All> for All
impl FromWireRef<All> for All
Sourcefn from_wire_ref(wire: &All) -> Self
fn from_wire_ref(wire: &All) -> Self
Converts the given reference to this type.
Sourceimpl Ord for All
impl Ord for All
Sourceimpl PartialOrd for All
impl PartialOrd for All
impl Copy for All
impl Eq for All
impl StructuralPartialEq for All