pub struct ComponentSelector {
pub moniker_segments: Option<Vec<StringSelector>>,
}Expand description
Specifies a pattern of component monikers which identify components being selected for.
Component selectors support wildcarding, which will glob a single “level” of a component moniker. eg: core/*/echo will match all echo instances running only in realms directly under core, but none nested further.
Component selectors also support a recursive wildcard, which will glob multiple “levels” of a component moniker. eg: core/** will match all component instances running under core/ and all descendants of it. Note that the wildcard does not select core itself. Clients that wish to choose a subtree including the root should pass two selectors, eg: core core/** The recursive wildcard is only allowed as the final segment of the selector.
Fields
moniker_segments: Option<Vec<StringSelector>>Trait Implementations
Sourceimpl Clone for ComponentSelector
impl Clone for ComponentSelector
Sourcefn clone(&self) -> ComponentSelector
fn clone(&self) -> ComponentSelector
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<ComponentSelector> for ComponentSelector
impl CompatFrom<ComponentSelector> for ComponentSelector
Sourcefn compat_from(value: ComponentSelector) -> Self
fn compat_from(value: ComponentSelector) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<ComponentSelector> for ComponentSelector
impl CompatFrom<ComponentSelector> for ComponentSelector
Sourcefn compat_from(value: ComponentSelector) -> Self
fn compat_from(value: ComponentSelector) -> Self
Converts
value into a value of this type.Sourceimpl Debug for ComponentSelector
impl Debug for ComponentSelector
Sourceimpl Default for ComponentSelector
impl Default for ComponentSelector
Sourcefn default() -> ComponentSelector
fn default() -> ComponentSelector
Returns the “default value” for a type. Read more
Sourceimpl<'a, ___E> Encode<ComponentSelector<'static>, ___E> for &'a ComponentSelectorwhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<ComponentSelector<'static>, ___E> for &'a ComponentSelectorwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<ComponentSelector<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<ComponentSelector<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ComponentSelector<'static>, ___E> for ComponentSelectorwhere
___E: Encoder + ?Sized,
impl<___E> Encode<ComponentSelector<'static>, ___E> for ComponentSelectorwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<ComponentSelector<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<ComponentSelector<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<ComponentSelector<'de>> for ComponentSelector
impl<'de> FromWire<ComponentSelector<'de>> for ComponentSelector
Sourcefn from_wire(wire_: ComponentSelector<'de>) -> Self
fn from_wire(wire_: ComponentSelector<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<ComponentSelector<'de>> for ComponentSelector
impl<'de> FromWireRef<ComponentSelector<'de>> for ComponentSelector
Sourcefn from_wire_ref(wire: &ComponentSelector<'de>) -> Self
fn from_wire_ref(wire: &ComponentSelector<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for ComponentSelector
impl Hash for ComponentSelector
Sourceimpl Ord for ComponentSelector
impl Ord for ComponentSelector
Sourcefn cmp(&self, other: &ComponentSelector) -> Ordering
fn cmp(&self, other: &ComponentSelector) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ComponentSelector
impl PartialEq for ComponentSelector
Sourceimpl PartialOrd for ComponentSelector
impl PartialOrd for ComponentSelector
impl Eq for ComponentSelector
impl StructuralPartialEq for ComponentSelector