pub struct LogInterestSelector {
pub selector: ComponentSelector,
pub interest: Interest,
}Fields
selector: ComponentSelectorinterest: InterestTrait Implementations
Sourceimpl CompatFrom<LogInterestSelector> for LogInterestSelector
impl CompatFrom<LogInterestSelector> for LogInterestSelector
Sourcefn compat_from(value: LogInterestSelector) -> Self
fn compat_from(value: LogInterestSelector) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<LogInterestSelector> for LogInterestSelector
impl CompatFrom<LogInterestSelector> for LogInterestSelector
Sourcefn compat_from(value: LogInterestSelector) -> Self
fn compat_from(value: LogInterestSelector) -> Self
Converts
value into a value of this type.Sourceimpl Debug for LogInterestSelector
impl Debug for LogInterestSelector
Sourceimpl<'a, ___E> Encode<LogInterestSelector<'static>, ___E> for &'a LogInterestSelectorwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<LogInterestSelector<'static>, ___E> for &'a LogInterestSelectorwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<LogInterestSelector<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<LogInterestSelector<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<LogInterestSelector<'static>, ___E> for LogInterestSelectorwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<LogInterestSelector<'static>, ___E> for LogInterestSelectorwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<LogInterestSelector<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<LogInterestSelector<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, LogInterestSelector<'static>>, ___E> for &'a LogInterestSelector
impl<'a, ___E> EncodeOption<Box<'static, LogInterestSelector<'static>>, ___E> for &'a LogInterestSelector
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, LogInterestSelector<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, LogInterestSelector<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, LogInterestSelector<'static>>, ___E> for LogInterestSelector
impl<___E> EncodeOption<Box<'static, LogInterestSelector<'static>>, ___E> for LogInterestSelector
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, LogInterestSelector<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, LogInterestSelector<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<LogInterestSelector<'de>> for LogInterestSelector
impl<'de> FromWire<LogInterestSelector<'de>> for LogInterestSelector
Sourcefn from_wire(wire: LogInterestSelector<'de>) -> Self
fn from_wire(wire: LogInterestSelector<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<LogInterestSelector<'de>> for LogInterestSelector
impl<'de> FromWireRef<LogInterestSelector<'de>> for LogInterestSelector
Sourcefn from_wire_ref(wire: &LogInterestSelector<'de>) -> Self
fn from_wire_ref(wire: &LogInterestSelector<'de>) -> Self
Converts the given reference to this type.
Sourceimpl PartialEq for LogInterestSelector
impl PartialEq for LogInterestSelector
impl StructuralPartialEq for LogInterestSelector