pub struct Selector {
pub component_selector: Option<ComponentSelector>,
pub tree_selector: Option<TreeSelector>,
pub tree_names: Option<TreeNames>,
}Expand description
Structured selector containing all required information for pattern-matching onto string-named properties owned by nodes in a data hierarchy, where data hierarchies belong to specific components.
These selectors are represented in text form as three segments, colon delimited, specifying: <component_moniker>:<node_selector>:<property_selector> Examples: Property selection: realm1/realm2/echo:root/active_users:user_count
Subtree selection: realm1/realm2/echo:root/active_users
Fields
component_selector: Option<ComponentSelector>tree_selector: Option<TreeSelector>tree_names: Option<TreeNames>Trait Implementations
Sourceimpl CompatFrom<Selector> for Selector
impl CompatFrom<Selector> for Selector
Sourcefn compat_from(value: Selector) -> Self
fn compat_from(value: Selector) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<Selector> for Selector
impl CompatFrom<Selector> for Selector
Sourcefn compat_from(value: Selector) -> Self
fn compat_from(value: Selector) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<Selector<'static>, ___E> for &'a Selectorwhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<Selector<'static>, ___E> for &'a Selectorwhere
___E: Encoder + ?Sized,
Sourceimpl<___E> Encode<Selector<'static>, ___E> for Selectorwhere
___E: Encoder + ?Sized,
impl<___E> Encode<Selector<'static>, ___E> for Selectorwhere
___E: Encoder + ?Sized,
Sourceimpl<'de> FromWireRef<Selector<'de>> for Selector
impl<'de> FromWireRef<Selector<'de>> for Selector
Sourcefn from_wire_ref(wire: &Selector<'de>) -> Self
fn from_wire_ref(wire: &Selector<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Ord for Selector
impl Ord for Selector
Sourceimpl PartialOrd for Selector
impl PartialOrd for Selector
impl Eq for Selector
impl StructuralPartialEq for Selector